% Exercise 2: Attenuation of a Collimated Beam
% Assumptions: 
%   + photon can be: absorbed, transmitted but NOT scattered
%   + same index of refraction: no refraction
%   + fixed step: absorption can only occur at the end of a step


% Parameters
n = 10000;      % Number of photons
seed = 1;       % Seed for random number generator
a = 1;          % Absorption in m^{-1}
dz = 0.2;       % Step of photon in m
max_depth = 20; % Maximum depth

% Initialization
rng(seed);
z = [0:dz:max_depth]';
nz = zeros(size(z));

% Main loop
for i=1:n
  zi = 1;
  % Approximation of Beer's Law (faster)
  while rand(1) > a * dz
    zi = zi + 1;
  end
  % Increment number of photon absorbed at a given depth
  nz(zi) = nz(zi) + 1;
end

% Plot Monte Carlo simulation results
figure(20); clf(20);
bar(z/2 + z, nz);
xlim([0 max_depth]);
xlabel('Depth (m)');
ylabel('Number of photons absorbed');

% Compare results 
hold('on');
plot(z/2 + z, dz*a*n*exp(-a*[0:1:size(z,1)-1]*dz), 'LineWidth', 2);
