% Exercise 3: Simple Monte-Carlo Simulation
% Assume:
%   + homogeneous medium
%   + photon can be: absorbed, transmitted, scattered, and reflected from the bottom
%   + same index of refraction: no refraction

clear
% Parameters
n = 10000;      % Number of photons
seed = 1;       % Seed for random number generator
a = 1;          % Attenuation in m^{-1}
b = 1;          % Scattering in m^{-1}

% Initialization
rng(seed);
c=a+b;
E = 0;          % Number of photon reflected
zA = NaN(n,1);  % Depth at which photon are absorbed

% Main loop
for i=1:n
  % Init photon
  z = 0;        % initial position depth
  muz = 1;    % incident light direction (collimated)
  while true
    % Move photon
    s = -log(rand)/c; % Geometric Path length
    % Compute new depth
    z = z + muz * s;
    % Check if photon is in medium
    if z < 0; E = E + 1; break; end % Count photon exiting water
    % Check if photon is absorbed
    if rand < a/c; zA(i) = z; break; end % Count photon absorbed
    % Photon scatters
    muz = 1 - 2*rand;% isotropic scattering
  end
end

% Show Results
fprintf('Photon reflected: %d %% \n', round(E/n*100,0));

% Plot Monte Carlo simulation results
figure(30); clf(30);
dz = 0.2;
max_depth = 10;
hist(zA,0.1:dz:max_depth);
xlim([0 max_depth]);
xlabel('Depth (m)');
ylabel('Number of photons absorbed');
